@@ -1,4 +1,5 @@
 """Cucumber json output formatter."""
+
 from __future__ import annotations
 
 import json
@@ -46,7 +47,6 @@ def unconfigure(config: Config) -> None:
 
 
 class LogBDDCucumberJSON:
-
     """Logging plugin for cucumber like json output."""
 
     def __init__(self, logfile: str) -> None:
@@ -64,7 +64,7 @@ class LogBDDCucumberJSON:
         result: dict[str, Any] = {}
         if report.passed or not step["failed"]:  # ignore setup/teardown
             result = {"status": "passed"}
-        elif report.failed and step["failed"]:
+        elif report.failed:
             result = {"status": "failed", "error_message": str(report.longrepr) if error_message else ""}
         elif report.skipped:
             result = {"status": "skipped"}
